==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/Radio.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { RadioLabelPosition_$type } from "./RadioLabelPosition";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Radio = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Radio, _super);
    function Radio() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.change = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(Radio.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.o = this.k;
        },
        enumerable: false,
        configurable: true
    });
    Radio.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Radio.prototype, "m", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "g", {
        get: function () {
            var ret_ = this.f.n("checked");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("checked", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "b", {
        get: function () {
            var ret_ = this.f.n("labelPosition");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(RadioLabelPosition_$type, EnumUtil.getEnumValue(RadioLabelPosition_$type, this.f.f(RadioLabelPosition_$type, ret_)));
            return EnumUtil.getEnumValue(RadioLabelPosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(RadioLabelPosition_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("labelPosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "h", {
        get: function () {
            var ret_ = this.f.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "j", {
        get: function () {
            var ret_ = this.f.n("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "i", {
        get: function () {
            var ret_ = this.f.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Radio.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.r("change", function (a) { return _this.change(_this, ComponentBoolValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("change");
        }
    };
    Radio.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.f.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("focus");
        }
    };
    Radio.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.f.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("blur");
        }
    };
    Radio.prototype.r = function () {
        this.nativeElement.click();
    };
    Radio.prototype.t = function (a) {
        this.nativeElement.focus(this.f.i(a));
    };
    Radio.prototype.o = function () {
        this.nativeElement.blur();
    };
    Radio.prototype.v = function (a) {
        this.nativeElement.setCustomValidity(this.f.i(a));
    };
    Radio.prototype.u = function () {
        this.nativeElement.reportValidity();
    };
    Radio.prototype.q = function () {
        this.nativeElement.checkValidity();
    };
    Radio.$t = markType(Radio, 'Radio', BaseElement.$);
    return Radio;
}(BaseElement));
export { Radio };

==> igniteui-react-18.7.0-beta.0.tgz: package/esm5/lib/Radio.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { RadioLabelPosition_$type } from "./RadioLabelPosition";
import { RadioChangeEventArgs } from "./RadioChangeEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Radio = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Radio, _super);
    function Radio() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.change = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(Radio.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.o = this.k;
        },
        enumerable: false,
        configurable: true
    });
    Radio.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Radio.prototype, "n", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.w("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "g", {
        get: function () {
            var ret_ = this.f.n("checked");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.w("checked", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "b", {
        get: function () {
            var ret_ = this.f.n("labelPosition");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(RadioLabelPosition_$type, EnumUtil.getEnumValue(RadioLabelPosition_$type, this.f.f(RadioLabelPosition_$type, ret_)));
            return EnumUtil.getEnumValue(RadioLabelPosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(RadioLabelPosition_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.w("labelPosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "h", {
        get: function () {
            var ret_ = this.f.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.w("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "j", {
        get: function () {
            var ret_ = this.f.n("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.w("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "m", {
        get: function () {
            var ret_ = this.f.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.w("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Radio.prototype, "i", {
        get: function () {
            var ret_ = this.f.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.w("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Radio.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.s("change", function (a) { return _this.change(_this, RadioChangeEventArgs.a(a)); });
        }
        else {
            this.f.v("change");
        }
    };
    Radio.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.f.s("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.v("focus");
        }
    };
    Radio.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.f.s("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.v("blur");
        }
    };
    Radio.prototype.s = function () {
        this.nativeElement.click();
    };
    Radio.prototype.u = function (a) {
        this.nativeElement.focus(this.f.i(a));
    };
    Radio.prototype.p = function () {
        this.nativeElement.blur();
    };
    Radio.prototype.w = function (a) {
        this.nativeElement.setCustomValidity(this.f.i(a));
    };
    Radio.prototype.v = function () {
        this.nativeElement.reportValidity();
    };
    Radio.prototype.r = function () {
        this.nativeElement.checkValidity();
    };
    Radio.$t = markType(Radio, 'Radio', BaseElement.$);
    return Radio;
}(BaseElement));
export { Radio };
